classdef line < graphics.shapes.shape
    %LINE Defines a graphics line object. See also SHAPE.
    
    methods

        function make_shape(self)
            rectangle(...
                'Parent', self.Transform, ...
                'FaceColor', [0.2 0.35 0.2]);
            state = pause('query');
            self.update_bounds(500, 10);
            pause('off');
            self.angle(0);
            pause(state);
        end
    
        function rv = width(self, new_width)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                self.update_bounds(self.length, new_width);
                rv = self;
            else
                box_position = get(self.box, 'Position');
                rv = box_position(4);
            end
        end
        
        function rv = length(self, new_length)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin ==2
                self.update_bounds(new_length, self.width);
                rv = self;
            else
                box_position = get(self.box, 'Position');
                rv = box_position(3);
            end
        end
        
        function rv = colour(self, new_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.box, 'FaceColor', new_colour);
                rv = self;
            else
                rv = get(self.box, 'FaceColor');
            end
        end
        
        function rv = color(self, new_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.box, 'FaceColor', new_colour);
                rv = self;
            else
                rv = get(self.box, 'FaceColor');
            end
        end
        
        function rv = start(self, new_start)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                self.update_line(new_start, self.end);
                rv = self;
            else
                a = self.angle;
                rv = self.centre - [0.5*self.length*cos(a), ...
                    0.5*self.length*sin(a)];
            end
        end
        
        function rv = end(self, new_end)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                self.update_line(self.start, new_end);
                rv = self;
            else
                a = self.angle;
                rv = self.centre + [0.5*self.length*cos(a), ...
                    0.5*self.length*sin(a)];
            end
        end
        
        % box, update_bounds and update_line are not part 
        % of the public interface!
        
        function rv = box(self)
            c = get(self.Transform, 'Children');
            rv = c(1);
        end
        
        
        function update_bounds(self, length, width)
            set(self.box, 'Position', ...
                [-length/2, -width/2, length, width]);
        end
        
        function update_line(self, startpt, endpt)
            length = sqrt((endpt(1)-startpt(1))^2+(endpt(2)-startpt(2))^2);
            centre = [(endpt(1)+startpt(1))/2, (endpt(2)+startpt(2))/2];
            angle = atan((endpt(2)-startpt(2))/(endpt(1)-startpt(1)));
            % correct for negative slopes
            if startpt(1) > endpt(1)
                angle = angle + pi;
            end
            state = pause('query');
            pause('off');
            self.length(length);
            self.centre(centre);
            self.angle(angle);
            pause(state);
        end
        
    end
end

% Copyright (c) Greg Phillips, 2010
% 8 November 2010
%
% This file is part of MATLAB-GRAPHICS.
% 
% MATLAB-GRAPHICS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% MATLAB-GRAPHICS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with MATLAB-GRAPHICS.  If not, see <http://www.gnu.org/licenses/>.



