classdef shape2D < graphics.shapes.shape
    %SHAPE2D Abstract base for rectangles and ellipses. See also SHAPE.
    % Provides methods to set and query height, width, colour, edge_width,
    % and edge_colour
    
    methods
        
        function rv = height(self, new_height)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                self.update_bounds(self.width, new_height, self.edge_width);
                rv = self;
            else
                outer_position = get(self.outer, 'Position');
                rv = outer_position(4);
            end
        end
        
        function rv = width(self, new_width)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin ==2
                self.update_bounds(new_width, self.height, self.edge_width);
                rv = self;
            else
                outer_position = get(self.outer, 'Position');
                rv = outer_position(3);
            end
        end
        
        function rv = colour(self, new_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.inner, 'FaceColor', new_colour);
                rv = self;
            else
                rv = get(self.inner, 'FaceColor');
            end
        end
                
        function rv = color(self, new_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.inner, 'FaceColor', new_colour);
                rv = self;
            else
                rv = get(self.inner, 'FaceColor');
            end
        end

        function rv = edge_width(self, new_edge_width)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                self.update_bounds(self.width, self.height, new_edge_width);
                rv = self;
            else
                outer_position = get(self.outer, 'Position');
                inner_position = get(self.inner, 'Position');
                rv = inner_position(1) - outer_position(1);
            end
        end
                
        function rv = edge_colour(self, new_edge_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.outer, 'FaceColor', new_edge_colour);
                rv = self;
            else
                rv = get(self.outer, 'FaceColor');
            end
        end
        
        function rv = edge_color(self, new_edge_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.outer, 'FaceColor', new_edge_colour);
                rv = self;
            else
                rv = get(self.outer, 'FaceColor');
            end
        end

        % Inner, outer and unpdate_bounds are not part 
        % of the public interface!
        
        function rv = inner(self)
            c = get(self.Transform, 'Children');
            rv = c(1);
        end
        
        function rv = outer(self)
            c = get(self.Transform, 'Children');
            rv = c(2);
        end
        
        function update_bounds(self, width, height, ew)
            set(self.outer, 'Position', ...
                [-width/2, -height/2, width, height]);
            set(self.inner, 'Position', ...
                [-width/2+ew, -height/2+ew, width-2*ew, height-2*ew]);
        end
        
    end
        
end

% Copyright (c) Greg Phillips, 2010
% 8 November 2010
%
% This file is part of MATLAB-GRAPHICS.
% 
% MATLAB-GRAPHICS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% MATLAB-GRAPHICS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with MATLAB-GRAPHICS.  If not, see <http://www.gnu.org/licenses/>.

