classdef text < graphics.shapes.shape
    %TEXT Defines a graphics text object. See also SHAPE.
    %   Text objects can go outside the displayable area.
    
    methods
        
        function make_shape(self)
            text(0, 0, 0, 'text', ...
                'Parent', self.Transform, ...
                'HorizontalAlignment', 'center', ...
                'VerticalAlignment', 'middle', ...
                'FontUnits', 'normalized', ...
                'FontSize', 0.1, ...
                'Color', [0 0 0]);
        end
        
        % rotation works totally different for text
        % the transform doesn't rotate it; rather, it has a 'Rotation'
        % property. Why? Oh, and it's in degrees, not radians!       
        function rv = angle(self, new_angle)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.text_object, 'Rotation', new_angle*180/pi);
                rv = self;
            else
                rv = get(self.text_object, 'Rotation')/180*pi;
            end
        end
        
        function rv = text_object(self)
            c = get(self.Transform, 'Children');
            rv = c(1);
        end
        
        function rv = colour(self, new_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.text_object, 'Color', new_colour);
                rv = self;
            else
                rv = get(self.text_object, 'Color');
            end
        end
        

        function rv = color(self, new_colour)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.text_object, 'Color', new_colour);
                rv = self;
            else
                rv = get(self.text_object, 'Color');
            end
        end
        
        function rv = height(self, new_height)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.text_object, 'FontSize', new_height/1000);
                rv = self;
            else
                rv = get(self.text_object, 'FontSize') * 1000;
            end
        end
        
        function rv = string(self, new_string)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.text_object, 'String', new_string);
                rv = self;
            else
                rv = get(self.text_object, 'String');
            end
        end

        function rv = font(self, new_font)
            error(nargchk(1, 2, nargin, 'struct'));
            if nargin == 2
                set(self.text_object, 'FontName', new_font);
                rv = self;
            else
                rv = get(self.text_object, 'FontName');
            end
        end

    end
    
end

% Copyright (c) Greg Phillips, 2010
% 8 November 2010
%
% This file is part of MATLAB-GRAPHICS.
% 
% MATLAB-GRAPHICS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% MATLAB-GRAPHICS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with MATLAB-GRAPHICS.  If not, see <http://www.gnu.org/licenses/>.

