function fresh
    %FRESH Create a fresh, empty drawing, erasing any old drawing.
    %   The new drawing will have no decorations, a square aspect ratio,
    %   axes running from 0 to 1000, and a white background rectangle.
    %   Pausing is turned on by default. It can be disabled in user
    %   scripts by calling
    %       pause off
    
    the_drawing = findobj('Name', 'The Drawing');
    if ishandle(the_drawing)
        clf(the_drawing);
    else
        the_drawing = figure('Renderer', 'painters');
    end
    set(the_drawing, 'ToolBar', 'none', 'MenuBar', 'none', ...
        'NumberTitle', 'off', 'Name', 'The Drawing', 'Renderer', 'OpenGL');
    axis([0 1000 0 1000]);
    axis square;
    axis off;
    hold on;
    gca;
    % background rectangle
    rectangle('Position', [0 0 1000 1000], 'FaceColor', [1 1 1], ...
        'LineStyle', 'none');
    % default drawing properties
    set(gca, 'DefaultRectangleHitTest', 'off');
    set(gca, 'DefaultRectangleLineStyle', 'none');
    pause on;

end

% Copyright (c) Greg Phillips, 2010
% 8 November 2010
%
% This file is part of MATLAB-GRAPHICS.
% 
% MATLAB-GRAPHICS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% MATLAB-GRAPHICS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with MATLAB-GRAPHICS.  If not, see <http://www.gnu.org/licenses/>.


