% A short example of matlab-graphics use, including input and animation.
% Creates a fresh drawing and places a red rectangle with a narrow blue
% border, 100 units wide and 50 high, at the drawing's bottom left corner.
% Asks the user to click somewhere, then moves the rectangle, in an animation
% lasting about one second, until it is centred where the user clicked.
% During the movement, the rectangle also completes one full rotation.
%
% Copyright (c) Greg Phillips, 20 September 2011, click_to_move.m
% ---
clc; clear;
import graphics.*
    
fresh;

STEPS = 25;
PAUSE_LENGTH = 1/STEPS;

rect = new_rectangle.width(100).height(50).edge_width(3).centre([50 25]);
rect.colour([1 0 0]).edge_colour([0 0 1]);

txt = new_text.string('Click to move the rectangle.').height(50);
end_point = get_point;
txt.visible(false);

move_step = (end_point - rect.centre)/STEPS;
rotation_step = (pi*2/STEPS);

for x = 1:STEPS
    rect.move(move_step).rotate(rotation_step);
    pause(PAUSE_LENGTH);
end
% This file is part of MATLAB-GRAPHICS.
% 
% MATLAB-GRAPHICS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% MATLAB-GRAPHICS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with MATLAB-GRAPHICS.  If not, see <http://www.gnu.org/licenses/>.

